@@ -84,9 +84,9 @@ def _get_other_versions(app):
         interesting_series = all_series
 
     # Reverse the list because we want the most recent to appear at
-    # the top of the dropdown. The "latest" release is added to the
-    # front of the list by the theme so we do not need to add it
-    # here.
+    # the top of the dropdown. Add the "latest" release to the
+    # front of the list.
+    interesting_series.append("latest")
     interesting_series.reverse()
     return interesting_series
 
@@ -312,8 +312,8 @@ def _builder_inited(app):
         'figure_align': 'H',
         'classoptions': ',openany',
         'preamble': r"""
-\usepackage{""" + pdf_theme_path + """}
-\\newcommand{\openstacklogo}{""" + theme_logo + """}
+\usepackage{""" + pdf_theme_path + r"""}
+\newcommand{\openstacklogo}{""" + theme_logo + """}
 """}
 
 
