@@ -11,14 +11,17 @@
 #    under the License.
 
 import datetime
+import os
 import os.path
 import subprocess
+import time
 
 from sphinx.util import logging
 
 LOG = logging.getLogger(__name__)
 
-_default_last_updated = datetime.datetime.now()
+_timeint = int(os.environ.get('SOURCE_DATE_EPOCH', time.time()))
+_default_last_updated = datetime.datetime.utcfromtimestamp(_timeint)
 
 
 def _get_last_updated_file(src_file):
@@ -32,7 +35,11 @@ def _get_last_updated_file(src_file):
                 '--', src_file,
             ]
         ).decode('utf-8').strip()
-    except (subprocess.CalledProcessError, OSError) as err:
+    # NOTE: we catch any exception here (instead of
+    # subprocess.CalledProcessError and OSError) because some projects (eg.
+    # neutron) do import eventlet in docs/source/conf.py which will patch
+    # the subprocess module and with that, the exception is not catched
+    except Exception as err:
         LOG.info(
             '[openstackdocstheme] Could not get modification time of %s: %s',
             src_file, err)
@@ -41,7 +48,7 @@ def _get_last_updated_file(src_file):
             try:
                 return datetime.datetime.strptime(last_updated_t,
                                                   '%Y-%m-%d %H:%M:%S')
-            except ValueError as err:
+            except ValueError:
                 LOG.info(
                     '[openstackdocstheme] '
                     'Could not parse modification time of %s: %r',
